@@ -1,10 +1,11 @@
 #! /usr/bin/env python
 """
-StochPy - Stochastic Modeling in Python (http://stompy.sourceforge.net)
+StochPy - Stochastic modeling in Python (http://stochpy.sourceforge.net)
 
-Copyright (C) 2010-2012 T.R Maarlveld, B.G. Olivier all rights reserved.
+Copyright (C) 2010-2013 T.R Maarlveld, B.G. Olivier all rights reserved.
 
 Timo R. Maarleveld (tmd200@users.sourceforge.net)
+Centrum Wiskunde & Informatica, Amsterdam, Netherlands
 VU University, Amsterdam, Netherlands
 
 Permission to use, modify, and distribute this software is given under the
@@ -55,9 +56,15 @@ __doc__ =   """
             ...
             """
 
-__version__ = '1.0.9'
+__version__ = '1.1.0'
 
-import os,shutil,readline,sys
+import os,shutil,sys
+
+try:
+    import readline
+    IsReadline = True
+except:
+    IsReadline = False
 
 try:
     from numpy.distutils.core import setup, Extension
@@ -68,8 +75,9 @@ except Exception, ex:
     os.sys.exit(-1)
 
 try:
-    import matplotlib.pyplot as plt
-    import pylab
+    import matplotlib
+    matplotlib.use('TkAgg')
+    import matplotlib.pyplot as plt    
 except:
     print "Warning: The Matplotlib module is not available, so it is impossible to create plots"
     print "Info: See http://matplotlib.sourceforge.net/ for more information about Matplotlib"
@@ -171,15 +179,16 @@ else:
     InitiateModels(model_dir)
  
 import modules
+import modules.PyscesInterfaces
 import lib
 import implementations
 from modules.SBML2PSC import SBML2PSC
 from modules.StochSim import SSA
-#from modules.NucleosomeModel import NucModel
-#from modules.NucleosomeSimulations import NucSim
 from modules.StochPyUtils import Utils
 from modules.StochPyCellDivision import CellDivision
 from modules.StochPyDemo import Demo
+#from modules.NucleosomeModel import NucModel
+#from modules.NucleosomeSimulations import NucSim
 
 def DeletePreviousOutput(path,type):
     """
@@ -213,30 +222,32 @@ def SaveInteractiveSession(filename='interactiveSession.py',path=output_dir):
     Input:
      - *filename*: [default = interactiveSession.py'] (string)
      - *path*: (string)
-    """   
-    historyPath = os.path.join(path,filename)
-    if os.path.exists(path):
-        readline.write_history_file(historyPath)
-        file_in = open(historyPath,'r')
-        history_list = file_in.readlines()
-        n_import_statement = 0
-        for command in history_list:            
-            if 'import stochpy' in command:
-               n_import_statement +=1
+    """
+    if not IsReadline:
+        print "Error: install 'readline' first"
+    elif IsReadline:
+        historyPath = os.path.join(path,filename)
+        if os.path.exists(path):
+            readline.write_history_file(historyPath)
+            file_in = open(historyPath,'r')
+            history_list = file_in.readlines()
+            n_import_statement = 0
+            for command in history_list:            
+                if 'import stochpy' in command:
+                   n_import_statement +=1
        
-        n = 0
-        file_out = open(historyPath,'w')
-        for command in history_list:
-            if "import stochpy" in command:             
-               n+=1
-            if n==n_import_statement:     
-                file_out.write(command)
-        file_out.close()
-        print "Info: Interactive session successfully saved at", historyPath
-        print "Info: use 'ipython", filename+"' to restart modelling with this interactive session"        
-    else:
-        print "Error: directory does not exist" 
-        
+            n = 0
+            file_out = open(historyPath,'w')
+            for command in history_list:
+                if "import stochpy" in command:             
+                   n+=1
+                if n==n_import_statement:     
+                    file_out.write(command)
+            file_out.close()
+            print "Info: Interactive session successfully saved at", historyPath
+            print "Info: use 'ipython", filename+"' to restart modelling with this interactive session"        
+        else:
+            print "Error: directory does not exist"         
     
 DeletePreviousOutput(temp_dir,'.dat')
 DeletePreviousOutput(temp_dir,'.xml')
@@ -253,7 +264,7 @@ print """
 #######################################################################
 #  StochPy: Stochastic modelling in Python                            #
 #  http://stompy.sourceforge.net                                      #
-#  Copyright(C) T.R Maarleveld, B.G. Olivier, F.J Bruggeman 2010-2012 #
+#  Copyright(C) T.R Maarleveld, B.G. Olivier, F.J Bruggeman 2010-2013 #
 #  Email: tmd200@users.sourceforge.net                                #
 #  VU University, Amsterdam, Netherlands                              #
 #  Centrum Wiskunde Informatica, Amsterdam, Netherlands               #
@@ -263,5 +274,3 @@ print """
 print "Version",__version__
 print "Output Directory:",output_dir
 print "Model Directory:", model_dir
-
-del Initiate
