@@ -93,7 +93,7 @@ class DirectMethod(PySCeS_Connector):
           self.propensities = copy.deepcopy(self.parse.propensities)
           self.species_stochmatrix = copy.deepcopy(self.parse.species)
           self.reagents = copy.deepcopy(self.parse.reagents)
-          self.rate_names = copy.deepcopy(self.parse.reactions)          
+          self.rate_names = copy.deepcopy(self.parse.Mod.__reactions__)        
           self.fixed_species = copy.deepcopy(self.parse.fixed_species)
           self.fixed_species_amount = copy.deepcopy(self.parse.fixed_species_amount)
           self.aDict = copy.deepcopy(self.parse.Mod.__aDict__)
