@@ -80,7 +80,7 @@ class FirstReactionMethod(PySCeS_Connector):
           self.n_species = len(self.X_matrixinit)
           self.propensities = copy.deepcopy(self.parse.propensities)
           self.reagents = copy.deepcopy(self.parse.reagents)
-          self.rate_names = copy.deepcopy(self.parse.reactions)          
+          self.rate_names = copy.deepcopy(self.parse.Mod.__reactions__)         
           self.fixed_species = copy.deepcopy(self.parse.fixed_species)
           self.fixed_species_amount = copy.deepcopy(self.parse.fixed_species_amount)
           self.aDict = copy.deepcopy(self.parse.Mod.__aDict__)
