@@ -75,7 +75,7 @@ class NextReactionMethod(PySCeS_Connector):
           self.species_stochmatrix = copy.deepcopy(self.parse.species)
           self.n_species = len(self.X_matrixinit)
           self.reagents = copy.deepcopy(self.parse.reagents)
-          self.rate_names = copy.deepcopy(self.parse.reactions)
+          self.rate_names = copy.deepcopy(self.parse.Mod.__reactions__)
           self.propensities = copy.deepcopy(self.parse.propensities)
           self.fixed_species = copy.deepcopy(self.parse.fixed_species)
           self.fixed_species_amount = copy.deepcopy(self.parse.fixed_species_amount)
