@@ -9,7 +9,7 @@ This program performs Optimized Explicit Tau-leaping algorithm, which is an appr
 
 Written by T.R. Maarleveld, Amsterdam, The Netherlands
 E-mail: tmd200@users.sourceforge.net
-Last Change: April 08, 2013
+Last Change: Augustus 21, 2013
 """
 
 ############################## IMPORTS ###################################
@@ -75,7 +75,7 @@ class OTL(PySCeS_Connector):
         self.species_stochmatrix = copy.deepcopy(self.parse.species)
         self.n_species = len(self.X_matrixinit)
         self.reagents = copy.deepcopy(self.parse.reagents)
-        self.rate_names = copy.deepcopy(self.parse.reactions)
+        self.rate_names = copy.deepcopy(self.parse.Mod.__reactions__)
         self.propensities = copy.deepcopy(self.parse.propensities)
         self.fixed_species = copy.deepcopy(self.parse.fixed_species)
         self.fixed_species_amount = copy.deepcopy(self.parse.fixed_species_amount)
@@ -197,13 +197,14 @@ class OTL(PySCeS_Connector):
                     a_ravel.insert(0,self.sim_t)
                     self.propensities_output.append(a_ravel)  
                 tauleapsteps +=1
+                self.timestep +=1                
             elif self.IsNegative:                               # Start feedback loop
                 IsNegative = True
                 self.sim_tau_prime = self.sim_tau_prime/2.0   
         elif self.IsExact:                                      # Direct SSA step
-            i = 0
+            i = 1
             ExactTimesteps = 100       
-            while i < ExactTimesteps and self.sim_t < settings.endtime and self.timestep < settings.timesteps:               
+            while (i < ExactTimesteps) and (self.sim_t < settings.endtime) and (self.timestep < settings.timesteps):               
                 self.sim_a_0 = self.sim_a_mu.sum() 
                 if self.sim_a_0 <= 0:                           # All reactants got exhausted
                     IsFinished = True           
@@ -235,17 +236,16 @@ class OTL(PySCeS_Connector):
                     timestep_output += [value for value in self.aDict_species]
                 timestep_output.insert(0,self.sim_t)
                 ###  End output Generation  ###
-                if i < ExactTimesteps:
-                    self.timestep +=1
-                    self.sim_output.append(timestep_output)                    
-                    self.Propensities()
-                    if self.IsTrackPropensities:
-                        a_ravel = list(self.sim_a_mu.ravel())
-                        a_ravel.insert(0,self.sim_t)
-                        self.propensities_output.append(a_ravel)
+                
+                self.timestep +=1                
+                self.sim_output.append(timestep_output)                    
+                self.Propensities()
+                if self.IsTrackPropensities:
+                    a_ravel = list(self.sim_a_mu.ravel())
+                    a_ravel.insert(0,self.sim_t)
+                    self.propensities_output.append(a_ravel)
                 i+=1                
-        #################### End possible feedback loop #################                 
-        self.timestep +=1
+        #################### End possible feedback loop #################       
         if IsFinished:
             break       
 
