@@ -6,7 +6,7 @@ The PySCeS parser is used to import a model written in the MDL of PySCeS. Furthe
 
 Written by T.R. Maarleveld, Amsterdam, The Netherlands
 E-mail: tmd200@users.sourceforge.net
-Last Change: May 17, 2013
+Last Change: September 20, 2013
 """
 
 import os,copy,time,sys,operator
@@ -489,14 +489,13 @@ class PySCeS_Connector(PyscesInputFileParser):
     self.reactants = []
     self.rate_eqs  = []
     self.propensities = []     
-    reaction_info = copy.copy(self.Mod.__nDict__)         # Reaction info from parser
-    self.reactions = copy.copy(self.Mod.__reactions__)
+    #self.reactions = copy.copy(self.Mod.__reactions__)
     IsReversible = False
     for r_id in self.Mod.__reactions__:
         temp_reactant = []
         temp_product  = []      
-        rate_eq = reaction_info[r_id]['RateEq']           # Rate eq. info      
-        L_parms   = reaction_info[r_id]['Params']         # Parm from rate eq.         
+        rate_eq = self.Mod.__nDict__[r_id]['RateEq']      # Rate eq. info      
+        L_parms = self.Mod.__nDict__[r_id]['Params']      # Parm from rate eq.         
         for parm in L_parms:                              # Replace parm values (fixed)                  
             parm = parm.replace('self.','')            
             if parm in self.Mod.__parameters__:
@@ -509,23 +508,22 @@ class PySCeS_Connector(PyscesInputFileParser):
             rate_eq = rate_eq.replace('self.%s' % parm,str(parm_value))
         rate_eq = rate_eq.replace('self.','__species__.') # Make a special object 'species' where all species amounts are stored 20 Oct 2011        
         self.propensities.append(rate_eq)                 # Add rate equation to props eq         
-        self.rate_eqs.append(reaction_info[r_id])
-        init_reagents = sorted(reaction_info[r_id]['Reagents'])# Remove fixed species      
+        self.rate_eqs.append(self.Mod.__nDict__[r_id])
+        L_reagents = sorted(self.Mod.__nDict__[r_id]['Reagents']) # Remove fixed species      
         L_s_indices = []                                  # Convert reagents of each reaction into species indexes
-        for reagent in init_reagents:
+        for reagent in L_reagents:
             reagent = reagent.replace('self.','')
             if reagent in self.species:
                 L_s_indices.append(self.species.index(reagent))	# reagents of reaction r 16/09
-        self.reagents.append(L_s_indices)
-      
-        for var in init_reagents:	                  # Determine the reactants of each reaction
-            var = var.replace('self.','__species__.')          
-            if (var+'*') in rate_eq:
-               temp_reactant.append(var[12:])          
-            elif var in rate_eq:
-               str_len = len(rate_eq)             
-               if str_len == (len(var) + rate_eq.index(var)):
-                   temp_reactant.append(var[12:])   
+        self.reagents.append(L_s_indices)               
+        
+        for reagent in L_reagents:	                  # Determine the reactants of each reaction
+            if self.Mod.__nDict__[r_id]['Reagents'][reagent] < 0:    # Reactant                          
+                reagent = reagent.replace('self.','')
+                temp_reactant.append(reagent)
+        for species in self.Mod.__nDict__[r_id]['Modifiers']:      
+             temp_reactant.append(species.replace('self.',''))
+                 
         self.reactants.append(temp_reactant)      
         if self.Mod.__nDict__[r_id]['Type'] == 'Rever':        
             IsReversible = True
@@ -541,30 +539,25 @@ class PySCeS_Connector(PyscesInputFileParser):
         temp_affects = []      
         for species in D_reagents:                   
             if D_reagents[species] != 0:
-                s_id = species.strip('self.')  
+                s_id = species.replace('self.','')  # September 19, 2013               
                 temp_affects.append(s_id)
         self.affects.append(temp_affects)
 
   def BuildDependencyGraph(self):
-    """ Function which builds a dependency graph """     
-    self.depends_on = copy.copy(self.reactants)
-    self.dep_graph = []   
+    """ Function which builds a dependency graph """
+    # Bug removed on September 19, 2013       
+    self.dep_graph = []       
     for i in xrange(len(self.affects)):
         change = []
         for species_name in self.affects[i]:
-            n=0
-            for rate_eq in self.propensities:
-                species = '__species__.' + species_name                
-                if species + '*' in rate_eq:                  
-                    change.append(n)
-                elif species in rate_eq:
-                    str_len = len(rate_eq)
-                    #print rate_eq,str_len,var,(len(var) + rate_eq.index(var))
-                    if str_len == (len(species) + rate_eq.index(species)):
-                        change.append(n)
-                n+=1                               
-        self.dep_graph.append(change)        
-
+            j=0
+            for reactants in self.reactants:
+                if species_name in reactants:
+                   change.append(j)
+                j+=1        
+        self.dep_graph.append(np.unique(change).tolist())               
+        
+    
 class RegularGridDataObj(object):    
     """
     This class is specifically designed to store the results of a stochastic time simulation on fixed time intervals
