@@ -1394,7 +1394,7 @@ class PySCeSParser:
                 self.InitParams.append(elem)
 
         # In self.nDict, clean rate equation pameter list of variables that occur in that reaction
-        for id in self.nDict.keys():
+        for id in sorted(self.nDict):
             # create 'Modifiers' key for each reaction - brett 20050606
             self.nDict[id].update({'Modifiers':[]})
             reagcomp = None
@@ -1413,7 +1413,7 @@ class PySCeSParser:
                         self.nDict[id]['Params'].remove(reag)
 
         # Check whether all parameters have been initialised and if not add to dictionary
-        for id in self.nDict.keys():
+        for id in sorted(self.nDict):
             cnames = [self.compartments[s]['name'] for s in self.compartments]
             for param in self.nDict[id]['Params']:
                 ##  print param
