@@ -47,8 +47,7 @@ def GetStochKitTimeSim(file_in,sim_time):
     IsInit = True
     frame_id = 0   
     for line in file_in:
-        sline = line.strip()
-        dat = sline.split('\t')
+        dat = line.strip().split('\t')        
         if IsInit and dat[0] == 'time':
             time_event_len = len(dat)
             species = dat[1:]                 
